@@ -327,9 +327,10 @@ def _create_contact_from_parsed(d):
                 v = None
             if k == "contact_name":
                 v = _split_geo_name(v)
-            if k == "contact_web_link":
-                if not v.startswith("http"):
-                    v = "http://" + v
+            if k == "contact_web_link"
+                if v is not None and type(v) == str and len(v):
+                    if not str(v).startswith("http"):
+                        v = "http://" + str(v)
             contact_dict[k.replace("contact_", "")] = v
     return contact_dict
 
