@@ -11,7 +11,7 @@ def test_ids_in_get_all_ontologies_from_obo_library():
 
 
 def test_get_an_ontology():
-    cl = ontology_from_obo_library('cl.obo')
+    cl = ontology_from_obo_library('cl.owl')
     assert 'CL:0000900' in cl
     assert isinstance(cl, pronto.Ontology)
     cl_inst = cl['CL:0000900']
