@@ -146,7 +146,7 @@ def parse_study(xml):
         for xref in d["xrefs"]:
             if xref["db"] == "pubmed":
                 if xref["id"] is not None:
-                    pubmeds.append(int(xref["id"]))
+                    pubmeds.append(xref["id"])
     d.update({"pubmed_ids": pubmeds})
     return d
 
@@ -1101,6 +1101,7 @@ def sra_object_generator(fh):
     for event, element in et.iterparse(fh):
         if (element.tag.lower() in validClasses) and (event == "end"):
             yield parsers.get(element.tag.title().lower())(element)
+            element.clear()
 
 
 class LiveList(Iterable):
